@@ -10,7 +10,8 @@ use serde_json::to_string_pretty;
 use std::fs::File;
 use std::path::PathBuf;
 
-#[derive(Clap)]
+#[derive(clap::ArgEnum)]
+#[allow(non_camel_case_types, clippy::upper_case_acronyms)]
 enum ParquetCompression {
     UNCOMPRESSED,
     SNAPPY,
@@ -21,8 +22,8 @@ enum ParquetCompression {
     ZSTD,
 }
 
-#[derive(Clap)]
-#[allow(non_camel_case_types)]
+#[derive(clap::ArgEnum)]
+#[allow(non_camel_case_types, clippy::upper_case_acronyms)]
 enum ParquetEncoding {
     PLAIN,
     RLE,
